@@ -41,3 +41,23 @@ class Graph:
                 for neighbor in current.neighbors:
                     stack.append(neighbor)
         return connected_component
+
+    def topological_sort(self) -> list[Node]:
+        num_nodes = len(self.nodes)
+        in_degree = [0 for _ in range(num_nodes)]
+        for node in range(num_nodes):
+            for neighbor in self.nodes[node].neighbors:
+                in_degree[neighbor.index] += 1
+        queue = []
+        for node in range(num_nodes):
+            if in_degree[node] == 0:
+                queue.append(self.nodes[node])
+        sorted_nodes = []
+        while queue:
+            node = queue.pop(0)
+            sorted_nodes.append(node)
+            for neighbor in self.nodes[node.index].neighbors:
+                in_degree[neighbor.index] -= 1
+                if in_degree[neighbor.index] == 0:
+                    queue.append(self.nodes[neighbor.index])
+        return sorted_nodes
