@@ -1,8 +1,8 @@
-from .text_block import Line, Page, Paragraph, Word
 from .bounding_box import BoundingBox
 from .constants import LINE, PAGE, WORD
 from .paragraph_detection.paragraph_extractor import ParagraphExtractor
 from .paragraph_detection.paragraph_sorter import sort_paragraphs
+from .text_block import Line, Page, Paragraph, TextBlock, Word
 
 
 class TextractParser:
@@ -12,7 +12,8 @@ class TextractParser:
         self.words: list[dict] = []
         self.lines: list[dict] = []
         self.page: dict = None
-        self.map_id_to_block: dict[str, dict] = {}
+        self.map_id_to_block_dict: dict[str, dict] = {}
+        self.map_id_to_block_object: dict[str, TextBlock] = {}
 
     def validate_args(self):
         """
@@ -55,8 +56,7 @@ class TextractParser:
         line = Line(bounding_box=bb)
         children_id = self.get_children_id(block_dict)
         for child_id in children_id:
-            child_block_dict = self.map_id_to_block[child_id]
-            child_block_object = child_block_dict["BlockObject"]
+            child_block_object = self.map_id_to_block_object[child_id]
             line.add_child(child_block_object)
         return line
 
@@ -83,13 +83,13 @@ class TextractParser:
             elif block_type == WORD:
                 self.words.append(block_dict)
 
-    def set_map_id_to_block(self):
+    def set_map_id_to_block_dict(self):
         """
         Get a map from block id to block dict
         """
         blocks_dict = self.textract_response["Blocks"]
         for block_dict in blocks_dict:
-            self.map_id_to_block[block_dict["Id"]] = block_dict
+            self.map_id_to_block_dict[block_dict["Id"]] = block_dict
 
     def parse_words(self):
         """
@@ -97,7 +97,7 @@ class TextractParser:
         """
         for word_dict in self.words:
             word = self.get_word(word_dict)
-            word_dict["BlockObject"] = word
+            self.map_id_to_block_object[word_dict["Id"]] = word
 
     def parse_lines(self):
         """
@@ -105,16 +105,19 @@ class TextractParser:
         """
         for line_dict in self.lines:
             line = self.get_line(line_dict)
-            line_dict["BlockObject"] = line
+            self.map_id_to_block_object[line_dict["Id"]] = line
 
     def extract_paragraphs(self) -> list[Paragraph]:
         """
         Parse the paragraphs
         """
-        lines = [line_dict["BlockObject"] for line_dict in self.lines]
+
+        lines = [
+            self.map_id_to_block_object[line_dict["Id"]] for line_dict in self.lines
+        ]
         paragraphs_extractor = ParagraphExtractor(lines)
         paragraphs = paragraphs_extractor.extract_paragraphs()
-        # paragraphs = sort_paragraphs(paragraphs)
+        paragraphs = sort_paragraphs(paragraphs)
         return paragraphs
 
     def extract_page(self, paragraphs: list[Paragraph]) -> Page:
@@ -131,7 +134,7 @@ class TextractParser:
         Parse the textract response and return the page object
         """
         self.split_blocks_by_type()
-        self.set_map_id_to_block()
+        self.set_map_id_to_block_dict()
         self.parse_words()
         self.parse_lines()
         paragraphs = self.extract_paragraphs()
